.. ai4water documentation

Welcome to ai4water's documentation!
====================================

.. image:: imgs/monogram.png

.. toctree::
   :maxdepth: 2

   installation
   quick_start
   understanding

.. toctree::
   :maxdepth: 2
   :caption: Modules

   model
   models
   datasets
   preprocessing
   postprocessing
   eda
   hpo
   experiments
   evapotranspiration
   utils
   auto_examples/index


paper
=====
AI4Water v1.0: An open source python package for modeling hydrological time series using data-driven methods

https://doi.org/10.5194/gmd-15-3021-2022

If you use ai4water in your research, consider citing it using following
BibTeX entry
::
    @article{atr2022GMD,
      title={AI4Water v1.0: An open source python package for modeling hydrological time series using data-driven methods},
      author={Abbas, Ather and Boithias, Laurie and Pachepsky, Yakov and Kim, Kyunghyun and Chun, Jong Ahn and Cho, Kyung Hwa},
      journal={Geoscientific Model Development},
      VOLUME = {15},
      YEAR = {2022},
      NUMBER = {7},
      PAGES = {3021--3039},
      URL = {https://gmd.copernicus.org/articles/15/3021/2022/},
      DOI = {10.5194/gmd-15-3021-2022}
      publisher={Copernicus}
    }

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
